@@ -1,45 +1,47 @@
 package Net::Gandi::Hosting::IP;
 
 use Moose;
+use Carp;
 
 extends 'Net::Gandi';
 
-
 =head1 NAME
 
+=encoding utf-8
+
 Net::Gandi::Hosting::IP - Interface to manage IP. 
 
 =cut
 
 has 'id' => ( is => 'rw', isa => 'Int' );
 
-=head1 ip_list
+=head1 list
 
 List IP associated with apikey that match the filter
 
 =cut
 
-sub ip_list {
+sub list {
     my ( $self, $params ) = @_;
 
     $params ||= {};
     return $self->call_rpc( 'ip.list', $params );
 }
 
-=head1 ip_count 
+=head1 count 
 
 List IP associated with apikey that match the filter
 
 =cut
 
-sub ip_count {
+sub count {
     my ( $self, $params ) = @_;
 
     $params ||= {};
     return $self->call_rpc('ip.count', $params);
 }
 
-=head1 ip_info
+=head1 info
 
 Return a mapping of the IP attributes.
 
@@ -47,36 +49,39 @@ Parameter: None
 
 =cut 
 
-sub ip_info {
+sub info {
     my ( $self ) = @_;
 
+    carp 'Required parameter id is not defined' if ( ! $self->id );
     return $self->call_rpc( 'ip.info', $self->id );
 }
 
-=head1 ip_update
+=head1 update
 
 Updates a IP’s attributes
 
 =cut
 
-sub ip_update {
+sub update {
     my ( $self, $params ) = @_;
 
+    carp 'Required parameter id is not defined' if ( ! $self->id );
+
     $params ||= {};
     return $self->call_rpc('ip.update', $self->id, $params);
 }
 
-#sub ip_attach {
+#sub attach {
 #    my ( $self, $iface_id ) = @_;
 #
-#    return $self->call_rpc('iface.ip_attach', $iface_id, $self->id);
+#    return $self->call_rpc('iface.attach', $iface_id, $self->id);
 #}
 
 
-#sub ip_detach {
+#sub detach {
 #    my ( $self, $iface_id ) = @_;
 #
-#    return $self->call_rpc('iface.ip_detach', $iface_id, $self->id);
+#    return $self->call_rpc('iface.detach', $iface_id, $self->id);
 #}
 
 =head1 AUTHOR
