@@ -1,18 +1,25 @@
 package Net::Gandi::Hosting::Iface;
 
 use Moose;
+use Carp;
 
 extends 'Net::Gandi';
 
 =head1 NAME
 
+=encoding utf-8
+
 Net::Gandi::Hosting::Iface - Interface to manage Iface. 
 
+=head1 DESCRIPTION
+
+A iface represent a network interface.
+
 =cut
 
 has 'id' => ( is => 'rw', isa => 'Int' );
 
-=head1 iface_list 
+=head1 list 
 
 List network interfaces associated to apikey that match the filter.
 
@@ -20,26 +27,46 @@ Available params are:
 
 =over 
 
-=item id 
-=item state 
-=item type
-=item vm_id
-=item items_per_page
-=item page
-=item sort_by
+=item *
+
+id
+
+=item *
+
+state 
+
+=item *
+
+type
+
+=item * 
+
+vm_id
+
+=item * 
+
+items_per_page
+
+=item *
+
+page
+
+=item * 
+
+sort_by
 
 =back
 
 =cut
 
-sub iface_list {
+sub list {
     my ( $self, $params ) = @_;
 
     $params ||= {};
     return $self->call_rpc( "iface.list", $params );
 }
 
-=head1 iface_count
+=head1 count
 
 Count network interfaces associated to apikey that match the filter
 
@@ -47,74 +74,84 @@ Available params are:
 
 =over 
 
-=item id 
-=item state 
-=item type
-=item vm_id
+=item * 
+
+id 
+
+=item * 
+
+state 
+
+=item * 
+
+type
+
+=item *
+
+vm_id
 
 =back
 
 =cut
 
-sub iface_count {
+sub count {
     my ( $self, $params ) = @_;
 
     $params ||= {};
     return $self->call_rpc('iface.count', $params);
 }
 
-=head1 iface_info
+=head1 info
 
 Returns informations about the network interface
 
 =cut 
 
-sub iface_info {
+sub info {
     my ( $self ) = @_;
 
+    carp 'Required parameter id is not defined' if ( ! $self->id );
     return $self->call_rpc( 'iface.info', $self->id );
 }
 
-=head1 iface_create
+=head1 create
 
 Create a iface.
 
 =cut
 
-sub iface_create {
+sub create {
     my ( $self, $params ) = @_;
 
     return $self->call_rpc( "iface.create", $params );
 }
 
-=head1 iface_update
+=head1 update
 
-Updates network interface’s attributes.
+Updates network interface attributes.
 
 =cut
 
-sub iface_update {
+sub update {
     my ( $self, $params ) = @_;
 
+    carp 'Required parameter id is not defined' if ( ! $self->id );
     return $self->call_rpc( "iface.update", $self->id, $params );
 }
 
-=head1
+=head1 delete
 
 Deletes a network interface.
 
 =cut
 
-sub iface_delete {
+sub delete {
     my ( $self ) = @_;
 
+    carp 'Required parameter id is not defined' if ( ! $self->id );
     return $self->call_rpc('iface.delete', $self->id);
 }
 
-=head1 DESCRIPTION
-
-A iface represent a network interface.
-
 =head1 AUTHOR
 
 Natal Ngétal, C<< <hobbestig@cpan.org> >>
